@@ -1,10 +1,14 @@
-import dask.array
-from .ngff_image import NgffImage
 from dataclasses import asdict
 
+import dask.array
+
+from .ngff_image import NgffImage
+from .rfc4 import itk_lps_to_anatomical_orientation
+
 
 def itk_image_to_ngff_image(
     itk_image,
+    add_anatomical_orientation: bool = True,
     # anatomical_axes: bool = False,
     # axis_names: List[str] = None,
     # axis_units: List[str] = None,
@@ -46,11 +50,14 @@ def itk_image_to_ngff_image(
         pass
 
     if image_dict is None:
-        raise RuntimeError('Could not import itk or itkwasm or input is not itk.Image or itkwasm.Image')
+        msg = (
+            "Could not import itk or itkwasm or input is not itk.Image or itkwasm.Image"
+        )
+        raise RuntimeError(msg)
 
     data = dask.array.from_array(image_dict["data"])
     ndim = data.ndim
-    if ndim == 3 and image_dict['imageType']['components'] > 1:
+    if ndim == 3 and image_dict["imageType"]["components"] > 1:
         dims = ("y", "x", "c")
     elif ndim < 4:
         dims = ("z", "y", "x")[-ndim:]
@@ -67,5 +74,15 @@ def itk_image_to_ngff_image(
     origin = image_dict["origin"]
     translation = {dim: origin[::-1][idx] for idx, dim in enumerate(spatial_dims)}
 
-    ngff_image = NgffImage(data, dims, scale, translation)
-    return ngff_image
+    # Add anatomical orientation if requested
+    axes_orientations = None
+    if add_anatomical_orientation:
+        axes_orientations = {}
+        for dim in spatial_dims:
+            orientation = itk_lps_to_anatomical_orientation(dim)
+            if orientation is not None:
+                axes_orientations[dim] = orientation
+
+    return NgffImage(
+        data, dims, scale, translation, axes_orientations=axes_orientations
+    )
