@@ -1,7 +1,6 @@
-from ngff_zarr import Methods, to_ngff_zarr, to_multiscales
-from zarr.storage import MemoryStore
+from ngff_zarr import Methods, to_multiscales
 
-from ._data import input_images, store_new_multiscales, verify_against_baseline
+from ._data import verify_against_baseline
 
 
 def test_gaussian_isotropic_scale_factors(input_images):
@@ -14,6 +13,16 @@ def test_gaussian_isotropic_scale_factors(input_images):
 
     baseline_name = "auto/DASK_IMAGE_GAUSSIAN.zarr"
     multiscales = to_multiscales(image, method=Methods.DASK_IMAGE_GAUSSIAN)
+    # store_new_multiscales(dataset_name, baseline_name, multiscales)
+    verify_against_baseline(dataset_name, baseline_name, multiscales)
+
+
+def test_gaussian_isotropic_scale_factors_two_components(input_images):
+    dataset_name = "brain_two_components"
+    image = input_images[dataset_name]
+    baseline_name = "2_4/DASK_IMAGE_GAUSSIAN.zarr"
+    multiscales = to_multiscales(image, [2, 4], method=Methods.DASK_IMAGE_GAUSSIAN)
+    # store_new_multiscales(dataset_name, baseline_name, multiscales)
     verify_against_baseline(dataset_name, baseline_name, multiscales)
 
 
